==> haskell-conduit-combinators-1.1.1-35-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.1.1
id: conduit-combinators-1.1.1-8Nkbm7txOFS7o6EksFT72q
key: conduit-combinators-1.1.1-8Nkbm7txOFS7o6EksFT72q
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: 80edf47103d7d6445f06833ede6e3c6a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/conduit-combinators-1.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/conduit-combinators-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/conduit-combinators-1.1.1
hs-libraries: HSconduit-combinators-1.1.1-8Nkbm7txOFS7o6EksFT72q
depends:
    base-4.10.0.0 conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz
    conduit-extra-1.1.16-K0CSi1r5Rzl3T85LRH0HhM transformers-0.5.2.0
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    void-0.7.2-KNNEd7XG9bDRysTndgnf2
    mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj filepath-1.4.1.2
    chunked-data-0.3.0-CDToOg5NysvDOf8n5FTTfe
    mono-traversable-1.0.2.1-9xgB18YyTetEiKftRDnY4v unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz=04052e0ff779aa08eefa6f6b9de183d0
             conduit-extra-1.1.16-K0CSi1r5Rzl3T85LRH0HhM=a6fea8b9e47bc51138a02f6c74aa4aa3
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg=9e7c576cd5d0cdeef0c68dbf576c880f
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=bfdecfdd320edc5290f0eb88b00ff7c3
             mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB=2bc42ccbc5907c6a67bc15ff0ea72d9c
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=b289e975ce7bd8a34701a798ad869335
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             chunked-data-0.3.0-CDToOg5NysvDOf8n5FTTfe=b4947284f07669b8940e8048e437096a
             mono-traversable-1.0.2.1-9xgB18YyTetEiKftRDnY4v=e9ebc8fbd25b748347f7e2923b7f3e8f
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-combinators-1.1.1-37-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.1.1
id: conduit-combinators-1.1.1-7XgQRpH5kmIGUyzqJgnbcw
key: conduit-combinators-1.1.1-7XgQRpH5kmIGUyzqJgnbcw
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
abi: ce99724755019c5ac8242f550174770a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/conduit-combinators-1.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/conduit-combinators-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/conduit-combinators-1.1.1
hs-libraries: HSconduit-combinators-1.1.1-7XgQRpH5kmIGUyzqJgnbcw
depends:
    base-4.10.0.0 conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1
    conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e transformers-0.5.2.0
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    void-0.7.2-KNNEd7XG9bDRysTndgnf2
    mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj filepath-1.4.1.2
    chunked-data-0.3.0-CDToOg5NysvDOf8n5FTTfe
    mono-traversable-1.0.2.1-9xgB18YyTetEiKftRDnY4v unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1=60ad65370a9da57d3d90715264a4baf8
             conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e=8535fcdffdc059c10de789d083424da6
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg=9e7c576cd5d0cdeef0c68dbf576c880f
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=bfdecfdd320edc5290f0eb88b00ff7c3
             mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB=2bc42ccbc5907c6a67bc15ff0ea72d9c
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=b289e975ce7bd8a34701a798ad869335
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             chunked-data-0.3.0-CDToOg5NysvDOf8n5FTTfe=b4947284f07669b8940e8048e437096a
             mono-traversable-1.0.2.1-9xgB18YyTetEiKftRDnY4v=e9ebc8fbd25b748347f7e2923b7f3e8f
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
